@@ -1,8 +1,6 @@
 import os
 from django.template import Template, Context
-from django.template.loader import render_to_string
 from bower.management.base import AppDirectoryCommand
-import shutil
 
 
 class Command(AppDirectoryCommand):
@@ -23,4 +21,4 @@ class Command(AppDirectoryCommand):
                     f.write(template.render(context))
 
         print "Add your dependencies to %s " % os.path.join(app_path,
-                                                            'bower.json')
\ No newline at end of file
+                                                            'bower.json')
